@@ -2,12 +2,12 @@ package Bread::Board::Container;
 BEGIN {
   $Bread::Board::Container::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Bread::Board::Container::VERSION = '0.25';
+{
+  $Bread::Board::Container::VERSION = '0.26';
 }
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
-use MooseX::Params::Validate;
+use MooseX::Params::Validate 0.14;
 
 use Bread::Board::Types;
 
@@ -182,9 +182,12 @@ sub resolve {
 
 __PACKAGE__->meta->make_immutable;
 
-no Moose; 1;
+no Moose::Util::TypeConstraints;
+no Moose;
 
+1;
 
+__END__
 
 =pod
 
@@ -194,7 +197,7 @@ Bread::Board::Container
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 DESCRIPTION
 
@@ -252,18 +255,9 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
-
-
-
-
